package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````L1<``#0```!XG@````0`!30`(``)
M`"@`'@`=``$``'`8?@``&'X``!A^```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````@?@``('X```4```````$`
M`0```*2-``"DC0$`I(T!`)@"``"L$@``!@```````0`"````M(T``+2-`0"T
MC0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DI(T`
M`*2-`0"DC0$`7`(``%P"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`GC9I=:/=[6J+)`MK3S/6JDK^RFT$
M````$`````$```!'3E4```````,````"`````````#T```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"```````````3```
M``````!-````3@```%``````````40````````!2````4P```%0```!5````
M`````%8```!8`````````````````````````````````````````%D```!:
M````7````%X```````````````````!?`````````&``````````80```&(`
M````````8P```&0`````````90```&8`````````````````````````````
M`&<``````````````&@`````````:0``````````````:@``````````````
M``````````"[XY)\:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PTZ/@^TG[
MH6Q@`*\TZ+_:5QO59-1\P^4_+'ZIG)NM2^/`XD?&`<_>1RT-%.*>(?_D#N&G
M`@K;S>.>6>^7>7=4/)2S`8MO#3J7"]EQ6!PS8MOM:PE#UD-%U>QK?YI\````
M``````````````````````#<$@````````,`"P``````I(T!```````#`!$`
M0`(`````````````$@```.$"`````````````!(```"U`@`````````````B
M````^@(`````````````$0```*<#`````````````!(````!````````````
M```@````I@$`````````````$@```)0"`````````````!(```#2`@``````
M```````2````,0$`````````````$@```!8#`````````````!$```!;`@``
M```````````2````EP``````````````$@```$<"`````````````!(```#8
M```````````````2````+`$`````````````$@```&("`````````````!(`
M```D`@`````````````2````Z@$`````````````$@````0#````````````
M`!(```#[`0`````````````2````"`(`````````````$@```(H!````````
M`````!$```#G```````````````2````1@``````````````$0```+L`````
M`````````!(```";`@`````````````2````C0(`````````````$0````P!
M`````````````!(```"R`0`````````````2````-@$`````````````$@``
M`'L"`````````````!(```"K`0`````````````2````0@$`````````````
M$@```.@"`````````````!(```!3```````````````2````'0``````````
M````(````!T"`````````````!(```#4`0`````````````2````,@(`````
M````````$@```$D!`````````````!(```"D`@`````````````2````@```
M````````````$@```)4!`````````````!(```#$`@`````````````2````
M%P$`````````````$@```(P``````````````!(````"`@`````````````2
M````.0(`````````````$@```&D!`````````````!(```!\`0``````````
M```2````8P``````````````$@```+```````````````!(```!-`@``````
M```````2````6`$`````````````$@```!8"`````````````!(```#:`@``
M```````````2````]0``````````````$@```"L"`````````````!(```!O
M```````````````2````^P(`````````````(0```*L"`````````````!(`
M``#)```````````````2````IP``````````````$@```"P`````````````
M`"````#\`@`````````````1````@P(`````````````$@```-D!````````
M`````!(````0`@`````````````2````S@$`````````````$@```'`"````
M`````````!(```#A`0`````````````2````N@$`````````````$@```$P$
M``!0H`$``````!``&`!F!```W3P``,P````2``T`=@,``'$?```$````$@`-
M`/4#``#Y.P``Y````!(`#0"Q!```>3L``(`````2``T`W`,``$$A```4````
M$@`-`+`#``#!+@``#`$``!(`#0!"!```.)`!``0````1`!<`600``%4A``#X
M`P``$@`-`)$$``#M)0``[````!(`#0#$`P``4*`!```````0`!@`PP,``%"@
M`0``````$``8`+H$``#I+```V`$``!(`#0!\!```;1X``$0````2``T`E0,`
M`-$E```<````$@`-``T$```0/@``!````!$`#P#/`P``*2$``!8````2``T`
MZ`,``-DF```0!@``$@`-`&8#``#U/0```@```!(`#0"$!```=1\``+0!```2
M``T`'`0``+$>``#`````$@`-`#($``"I/0``3````!(`#0!1!```4*`!````
M```0`!@`AP,``#R0`0``````$``8`*,$``!-)0``A````!(`#0`"!````)`!
M```````@`!<`<`0``#R0`0``````$``8``8$``"Q%P```````!(`#0``!```
M`)`!```````0`!<`O`,``#R0`0``````$``7`/4"``#I%0``R`$``!(`#0``
M7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%])
M5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?9W9?
M9F5T8VAP=@!097)L7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?9V5T
M7W-V`%!E<FQ?;F5W6%,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<G5N`'!E<FQ?
M<&%R<V4`4&5R;%]S=E]S971P=@!097)L7W-V7W-E='!V;@!P97)L7V-O;G-T
M<G5C=`!P97)L7V1E<W1R=6-T`%!E<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R
M;%]A;&QO8P!097)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S
M869E<WES;6%L;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`4$Q?=&AR7VME>0!?
M7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T`&QS965K-C0`<'1H<F5A9%]G
M971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`
M9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD
M:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A
M=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`
M<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK
M`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N
M=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M<&5R;"TU+C,T+G-O`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN
M=7@M87)M:&8N<V\N,P!?7VQI8F-?8W-U7V9I;FD`<&%R7V-U<G)E;G1?97AE
M8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?8F%S96YA;64`<&%R
M7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`7U]D871A7W-T87)T
M`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?
M8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`
M<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A
M<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<VAA7VEN:70`6%-?26YT
M97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-``````````"``(``@`"``(````#
M``(``@`"``0``@````(```````(``@`"``(``@`"`````````````@`"````
M`P````(``P`"``(```````(``@`"`````@````,``@```````@`"````````
M`````@````(``@````(````"``(``````````@`"``(``@`#``(``@`#``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!`%(#```0````(````!1I:0T```0`T`0`````
M```!``$`.`,``!`````@````%&EI#0```P#0!`````````$``0!(`P``$```
M```````4:6D-```"`-`$````````J(T!`!<```"LC0$`%P```+"-`0`7````
MQ(\!`!<```#HCP$`%P```/"/`0`7````")`!`!<````,D`$`%P```!20`0`7
M````&)`!`!<````<D`$`%P```""0`0`7````))`!`!<````LD`$`%P```#"0
M`0`7````.)`!`!<```#(CP$`%04``,R/`0`5"```T(\!`!4-``#4CP$`%0\`
M`-B/`0`5&0``W(\!`!4;``#@CP$`%1X``.2/`0`5)P``[(\!`!4T``#TCP$`
M%3X``/B/`0`50P``_(\!`!5$``#0C@$`%@,``-2.`0`6!```V(X!`!8%``#<
MC@$`%@<``.".`0`6"0``Y(X!`!8*``#HC@$`%@L``.R.`0`6#```\(X!`!8.
M``#TC@$`%A```/B.`0`6$0``_(X!`!82````CP$`%A,```2/`0`6%```"(\!
M`!85```,CP$`%A8``!"/`0`6%P``%(\!`!88```8CP$`%AH``!R/`0`6'```
M((\!`!8=```DCP$`%A\``"B/`0`6(```+(\!`!8A```PCP$`%B(``#2/`0`6
M(P``.(\!`!8D```\CP$`%B4``$"/`0`6)@``1(\!`!8G``!(CP$`%B@``$R/
M`0`6*0``4(\!`!8J``!4CP$`%BL``%B/`0`6+```7(\!`!8M``!@CP$`%BX`
M`&2/`0`6+P``:(\!`!8P``!LCP$`%C$``'"/`0`6,@``=(\!`!8S``!XCP$`
M%C4``'R/`0`6-@``@(\!`!8W``"$CP$`%C@``(B/`0`6.0``C(\!`!8Z``"0
MCP$`%CL``)2/`0`6/```F(\!`!8]``"<CP$`%D```*"/`0`600``I(\!`!9"
M``"HCP$`%D4``*R/`0`61@``L(\!`!9'``"TCP$`%D@``+B/`0`620``O(\!
M`!9*``#`CP$`%DL```A`+>E$`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7,>P$`
M`,:/XA?*C.+,^[SE`,:/XA?*C.+$^[SE`,:/XA?*C.*\^[SE`,:/XA?*C.*T
M^[SE`,:/XA?*C.*L^[SE`,:/XA?*C.*D^[SE`,:/XA?*C.*<^[SE>$?]YP#&
MC^(7RHSBD/N\Y0#&C^(7RHSBB/N\Y0#&C^(7RHSB@/N\Y0#&C^(7RHSB>/N\
MY0#&C^(7RHSB</N\Y0#&C^(7RHSB:/N\Y7A'_><`QH_B%\J,XES[O.4`QH_B
M%\J,XE3[O.5X1_WG`,:/XA?*C.)(^[SE`,:/XA?*C.)`^[SE`,:/XA?*C.(X
M^[SE`,:/XA?*C.(P^[SE`,:/XA?*C.(H^[SE`,:/XA?*C.(@^[SE`,:/XA?*
MC.(8^[SE`,:/XA?*C.(0^[SE`,:/XA?*C.((^[SE`,:/XA?*C.(`^[SE`,:/
MXA?*C.+X^KSE`,:/XA?*C.+P^KSE`,:/XA?*C.+H^KSE`,:/XA?*C.+@^KSE
M`,:/XA?*C.+8^KSE`,:/XA?*C.+0^KSE`,:/XA?*C.+(^KSE`,:/XA?*C.+`
M^KSE`,:/XA?*C.*X^KSE`,:/XA?*C.*P^KSE`,:/XA?*C.*H^KSE`,:/XA?*
MC.*@^KSE`,:/XA?*C.*8^KSE`,:/XA?*C.*0^KSE>$?]YP#&C^(7RHSBA/J\
MY0#&C^(7RHSB?/J\Y0#&C^(7RHSB=/J\Y0#&C^(7RHSB;/J\Y0#&C^(7RHSB
M9/J\Y0#&C^(7RHSB7/J\Y0#&C^(7RHSB5/J\Y0#&C^(7RHSB3/J\Y0#&C^(7
MRHSB1/J\Y0#&C^(7RHSB//J\Y0#&C^(7RHSB-/J\Y0#&C^(7RHSB+/J\Y0#&
MC^(7RHSB)/J\Y0#&C^(7RHSB'/J\Y0#&C^(7RHSB%/J\Y0#&C^(7RHSB#/J\
MY0#&C^(7RHSB!/J\Y0#&C^(7RHSB_/F\Y0#&C^(7RHSB]/F\Y0#&C^(7RHSB
M[/F\Y0#&C^(7RHSBY/F\Y0#&C^(7RHSBW/F\Y7"U3_2`7*WK#`S,^-`/6TV(
ML%M+?43-Z000`Y(%J.M8!*D#JE=,&V@'DT_P``/_]S[O54I\1%5+HEC@6!%&
M`O#G^U-+XU@=>``M:]!12^18(&C_]]#O`T8@:)/XQB-"\`("@_C&(__WQN\%
MG2H=`S6R\8!/D/C&,T/P`0.`^,8S<]*0`/_WUNY#2T1*>T0$G'I$$6@B:%A@
M04L"8'M$PV`%FT!*`2N!8'I$0F!?W2$=!.N##@#Q#`Q1^`1+<45,^`1/^=$#
M,SA.`"$`D2I&0/@C$'Y$-4D#1O!H>43_]RKO!$9XLS)-!JY]1.AH__>$[C!(
M,49X1`#P]?A`LRY+>T38:/_W3.[_]PKO+$H<2WI$TU@::`>;6D!/\``#*=$@
M1@BP<+W_]WKN)4IZ1-!@$+/_]R[N%TOD6"!H__=<[X#X>U>%Y_!H__<L[P1&
MRN>H:!"Q`?#!^]'G&D@Q1GA$`/#!^*A@`"C)T//G__<"[P0CJ>?_]RCN`2#_
M]XSNQ'@!``P!``"D>`$`*`$``#`!```8`0``%`$``,AY`0"\>0$`3"L``#PK
M``"">0$`,P<``&QY`0"\*```5GD!`,IW`0`J>0$`]"<``$_P``M/\``.`KQJ
M1@2T`;3?^"2@"*.:1-_X(,!:^`S`3?@$S09+6O@#,`9(6O@``/_W-.[_]^+N
MW'8!```!```D`0``+`$``!0PG^44()_E`S"/X`(@D^<``%+C'O\O`1/__^J\
M=@$`(`$```9(!TMX1`=*>T2#0GI$`]`%2]-8`[$81W!'`+\8>`$`%'@!`)AV
M`0`(`0``"$@)27A$"4IY1`D:>D3+#P/KH0%)$`/0!4O36`.Q&$=P1P"_['<!
M`.AW`0!L=@$`-`$```BU3_2`7*WK#`S,^/@/"DL*2GM$>D0;>&.Y"4O36!NQ
M"$AX1/_W..W_][K_!DL!(GM$&G`(O0"_JG<!`#!V`0`$`0``#G4!`(QW`0"^
MYP"_+>GX0T_T@%RMZPP,S/C@#Q]+@49[1``H-M`>2IM8T_@`@+CQ``\QT`5X
M#T8`+1B_/2T4OP$E`"43T=CX`$!LL49&($8J1DE&__=$[A"Y8UT]*Q#05O@$
M3P`L\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"07AYP$UINL(!BQ$MA`^8"!&
MO>CX@P1&Y^=$1N7GX'4!`#@!```MZ?!!3_2`7*WK#`S,^'`/-TJ>L#=+>D33
M6!MH'9-/\``#$+$#>`1&8[DS2C%+>D336!IH'9M:0$_P``-6T1ZPO>CP@?_W
M/NT%1@`H[=`K3W]$*$;_]]KM`"@VT,-\`/$3!BXK`M%S>``K\M##?"XK,M`@
M1O_W5NV`1C!&__=2[4!$`C#_]RKM.T9/\/\R`2$!E@"4!D;_]V3M`JHQ1@,@
M__?&[0$P,$8%T`:;`_1P0[/U@$\7T/_WUNPP1O_WF.PH1O_WI.T`*,C1*$;_
M]\[M($;_]YKLJ.=S>"XKR=&S>``KMM#%Y__WB__FY__WK.Q&=0$`#`$``"YU
M`0`D)0``$+5/](!<K>L,#,SXB`_?^&3`G+`82P1&_$1J1@,@(49<^`,P&V@;
MDT_P``/_]YCMH+D$FP/T<$.S]2!/&+^S]8!/#=`-2@Q+>D336!IH&YM:0$_P
M``,+T1RP$+T`(/'G`B$@1O_W0.VP^H#P0`GIY__W:NQ$=`$`#`$``!1T`0`0
MM4_T@%RMZPP,S/CX#P1&__?([$,>(T2<0CB_&D8#TRO@HD(31BC0$T82^`$9
M+RGWT)Q"(=(!.YQ"(-`:>"\J^=$!.P+@$7@O*031G$(:1@/Q_S/WTQ(;DQRS
M]8!?B+\`(`G8#4@A1@$R3_2`4WA$!$;_]QSL($80O9Q"X=$C>"\K!=`&2+WH
M$$!X1/_W%+P$2+WH$$!X1/_W#KSZ=`$`<B,``"XC```MZ?!#3_2`7*WK#`S,
M^```3/@H#`1&+$@.1BQ)>$2M]8!=@[!`]O]R05@-]8!3*$@!KPEH66!/\``!
M!#-X1#E&__<4[-_XC(#X1+#Q``P;W0*M#/'_.4U$%?@$/(.[N?$`#Q'02D8O
M(3A&__>D[%BQ&4M8^`,P&&C_]^KL2T8Z1B%&__>V[`G@$TM8^`,P&&C_]][L
M,D8A1O_WXNL/20WU@%,*2@0S>42*6!%H&FA10$_P``(&T0WU@%T#L+WH\(/A
M1L_G__>LZQAS`0`,`0``'",``.QR`0`4`0``CG(!`"WI\$=/](!<K>L,#,SX
MV`\+>`Q&5TF"L%=*/2MY1`B_`30%1M_X5(&*6"!&^$02:`&23_```O_W\NMI
M1@9&*$;_]P[^@48`*%;0__?HZX9"2=E+2P"?6/@#@+\`*W@`*QB_/2L4OP$C
M`",'T"M&$_@!+P`J&+\]*OG16QNP'-CX`&`81/_WINOP4?BQ`)DH1MCX`"`0
M^`$[4O@A$``K&+\]*PMP"=!*'!#X`3L11CTK&+\`*P+X`3OVT0I&/2,+<!3X
M`3L"^`$_`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]Z/"'"?'_.13X`3L)
M^`$_`"OYT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ`0D`*OC1`S&)`!M*
M>D03:+NY"$8!(Q-@__=4ZX)&`"C,T#E&3^J)!SI&__?.ZLCX`*`)\0$#`")*
M^",@S?@`D(3G.$;_]PCK@D;(^````"BTT$_JB0?LYYE&""'5Y__WZ.H`OSAR
M`0`,`0``*'(!`#@!``"$<0$`M'(!`#"U3_2`7*WK#`S,^.@/$4R#L!%+?$3E
M6"AH__?DZRAH__?@ZPU*#DL.2:)8>T1Y1``D__=:ZRAH__?4ZPI+"TH+27M$
M>D3-Z0`T>43_]W;K`[`PO;1P`0`4`0``$`$``#!?``#.(```CB,``*D.``#.
M(```$+5/](!<K>L,#,SX^`\(3`A+?$3C6!AH__>JZP9*!TL'2:)8>T2]Z!!`
M>43_]R"[0G`!`!0!```0`0``Q%X``%X@``!PM4_T@%RMZPP,S/@``*SU@%S,
M^```3/@H#"1)K?4`72-*AK!Y1`WU`%,4,P.LBE@-]8!6$#82:!I@3_```O_W
MP.H<24'R`0(;2WE$>T3-Z0`!`2$@1O_WWNH@1D_T@%(Q1O_W<NH$'KB_`"4*
MVV`<__>.Z@5&*+$B1C%&__<8Z@`C*U4-20WU`%,)2A0S>42*6!%H&FA10$_P
M``($T2A&#?4`70:P<+W_]RCJ[&\!``P!```Z(```+"```()O`0#_]YZ_+>GP
M3T_T@%RMZPP,S/@``$SXL`Q:3*WUA%U:2H.P?$0&1@WQ&`A82*)8#?6$4WA$
M#49!1@0S$F@:8$_P``+_]XO\+R$$1C!&__=PZL"Q3T@Q1GA$__=0_C!&34D-
M]8132$H$,WE$BE@1:!IH44!/\``"0/""@`WUA%T#L+WH\(\P1O_W2.I#27E$
M@48H1O_WL.H`*-O00$L'1M_X`*%[1`63/TOZ1'M$!),[>``K/]`LL3E&($;_
M]V[I`"A"T#A&__<HZD(>NQBZ7"\J!M$`)1UP`3@3^`$M+RKYT`GQ`0,81+#U
M@%^RVB&M+DH!(5-&>D0H1LWI`')/](!2`I;_]RCJ0D8I1@,@__>*ZBBY"IL#
M]'!#L_4`3QW0(TD`('E$__=FZ@=&`"^1T#MX`"N_T02S(W@N*P+0!9\!(,[G
M8W@`*_G1&4D`('E$__=2Z@=&`"_JT7OG`2$H1O_W/NH`*-O1$T@I1GA$__?&
M_2A&__=>Z7+G!)\!(+#G__=>Z0"_+F\!``P!``"6'P``?A\``.AN`0!8'P``
MEAX``$`?``".'@``?!X``,(>``"8'@``:AX```-X.[%"'"\K"+\01A+X`3L`
M*_C1<$<`OQ"Q`W@#L<WD`4AX1/_W)KE>'0``<+5/](!<K>L,#,SXP`_=2HRP
MW_ATPPWQ"`[<2WI$_$3;3@SQ#`S;3=-8?D0!K'U$&V@+DT_P``.\Z`\`KN@/
M`+SH#P"NZ`\`W/@`,*[X`#`A1C!&__>0^["QSTL!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]WK[`"CHT<1.?D0A1C!&__=R^["QP$L!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]US[`"CHT;9.
M?D0A1C!&__=4^["QL4L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]S[[`"CHT:A.?D0A1C!&__<V^["QHDL!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]R#[`"CHT9I.?D0A1C!&__<8^["QDTL!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]P+[`"CHT8Q.
M?D0A1C!&__?Z^K"QA$L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]^3Z`"CHT7Y.?D0A1C!&__?<^K"Q=4L!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\;Z`"CHT7!.?D0A1C!&__>^^K"Q9DL!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]ZCZ`"CHT6).
M?D0A1C!&__>@^K"Q5TL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZ
MT2%&,$;_]XKZ`"CHT51.?D0A1C!&__>"^K"Q2$L!F.M8&6@!ZX`#6FA!^"`@
M`"KOT`0S6FA#^`0K`"KZT2%&,$;_]VSZ`"CHT49.?D0A1C!&__=D^K"Q.4L!
MF.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]T[Z`"CHT3A(
M(49X1/_W1_H!1ABQ-DAX1/_W$?PU2"%&>$3_]SSZ`488L3)(>$3_]P;\,4@A
M1GA$__<Q^@%&J+$O2'A$__?[^RY)+DAY1'A$__?U^RU*%DMZ1--8&F@+FUI`
M3_```QW1#+!PO2A((49X1/_W%/H!1B"Q)4AX1/_WWOOAYR1)#?$9``HB>43_
M]W#H`"C8T2!(#?$C`7A$__?.^]'G_O=L[P"_4&T!`.);```,`0``XAT``#YM
M`0`X`0``CAT``%H=```J'0``]AP``,H<```N'```7AP``"X<``#^&P``2AL`
M`)`;``!L&P``CAL``%(:``",&P``R!H``*8;```,&P``.FH!`&(;``#Z&@``
M6AL``-H:````M4_T@%RMZPP,S/CP#Q=+@[`727M$%TIY1!AHBEA#'!)H`9)/
M\``"#-`32A%+>D336!IH`9M:0$_P``,3T0.P7?@$^PU(:49X1/_WF?DPL0!X
M,"@8OP`H%+\!(``@"$M[1!A@X>?^]_SN`+^@:@$`7&D!``P!``!&:0$`$!H`
M`%1J`0`(M4_T@%RMZPP,S/CX#_[WK.[^]Y[N`+$`:`B]\+5/](!<K>L,#,SX
MT`\N2H>P+DX%1BY+>D1^1`2ITU@P1AMH!9-/\``#__=9^1"Q`W@$1HNY)THE
M2WI$TU@::`6;6D!/\``#/-$C2"E&>$0'L+WH\$#_]Q.[*4;^]UCN6+$>2AI+
M>D336!IH!9M:0$_P``,FT0>P\+TH1O[W#N\'1B!&_O<*[SA$`C#^]^+N$TL4
M2@$A>T0"E'I$`)4!DD_P_S($1O[W&.\/2@A+>D336!IH!9M:0$_P``,$OR%&
M,$;%T/[W?.Z\:`$`'AH```P!``"::`$`ZAD``&YH`0#6&```SA@``"9H`0`M
MZ?!/3_``#*WK#`Q/]`!.K.L.#JSU@%S,^```]$7YT:[U@%[.^-@.K?4!3=_X
M3%6!L-_X3$5]1`WU`$$'D'Q$W_A`!2(=_#%`KZ?Q=`,$\1`,*%BG\5P%*#2G
M\6@.`&@(8$_P``"G\>`&!\K?^!BE^D2#Z`<`O.@/``_%G.@#`(7H`P"4Z`<`
MCN@'`#%&W_C\!'A$__>N^""Q`W@$1@`K0/!@@?[WW.W^]\[M`"@`\'&!!6@`
M+0#PEX$H1O[W>.Y```$P_O=0[BIX@$:"L=_XP+1$1OM$($8`DEM&3_#_,@$A
M`C3^]X+N%?@!+P`J\M'?^*`$I_%8!7A$`N!5^`0+B+$Q1O_W=O@$1@`H]M`#
M>``K\]#_]SKY`"COT"!&_O?4[01&T+FG\70+3_``"0?KB0)2^'1,A+$)\0$%
M"^N%!2)X4K$@1@GQ`0G_]Q_Y`"A<T57X!$L`+/+1`"0@1O[W*.Z#1D!&_O<D
M[EA$`/($2UA&_O?Z[=_X(#1/\/\R`2%[1`*3W_@4-,WX#(![1`&3W_@,-`"4
M>T2`1O[W*.Y/].!Q0$;^]S;N`3`%T?[W&.X!:!$I0/#&@#)&048#(/[WENX%
M1DBS]TD'F_=*6O@!``$A&VAZ1,WX`(!/\``*`&C^]S;N\4D-]0!#YDK\,WE$
MBE@1:!IH44!/\``"0/"\@5!&#?4!30&PO>CPCR!&_O=<[01&`"B*T*#G5_C0
M/`/T<$.S]8!/SM%7^,A,_O<8[81"R-%7^-`\P_,(`[/UX'_!T5A&_O>0[3%&
M@D;82'A$_O?0_P`H`/#)@`>;'&C^]S3M`48@1O_W&?N#1@`H`/"]@%A&_O><
M[0,H!$8/V<U)!#A81'E$_O?4[$"Y!"P`\"^!7$04^`4\+RL`\"F!QDQ\1"-H
M6AP`\*6``"L`\+>`PDG#2'E$W_@,DWA$PD__]VGYPD[^]VCMP4O"2@$A>T0!
MD\%+>D3-^`"`^40#DGM$3_#_,G]$?D0"D%!&_O=^[13@_O=V[0-H$2L7T?[W
M3.T!-4M&(D8!(<WI`U?-^`"`A$901LWI`6S^]VCM3_3@<5!&_O=X[4,<!$;B
MT$!&_O>F[*I(449X1/_W+/E01O_WZ?U/YY=*!YM:^`(`3_``"J-*&VAZ1,WI
M`($!(0!H_O=X[3_G__?6_9Y)ADH-]0!#>43\,XI8$6@::%%`3_```D#P^H`@
M1@WU`4T!L+WH\$_^]YB\@$:G\6@$!^N(`U/X:`S(L0CQ`0L$ZXL%!.!5^`0+
MB+$+\0$+,4;81O[W&O\`*/30`W@`*_'0_O=^[`5&`"A_]'*NX.<-((--_O?$
M[%,B?42`1G+FJ$;4YP>;T_@`L#[G?4@Q1GA$_O?[_@`H`/"+@`-X`"L8OS`K
M%;\!(P`C`2,C8!B_(V!_]$FO6$8`(?[WG.P$1@`H/_1!KST?3_#_,V_P$0("
M)@"6_O=\[`8B*48@1O[W!NP7^`0\&[D7^`,\0RMBT``C`"(`DR!&`"/^]VKL
M`?`;^`9&`^`I1C!&`?!5^$_T`$(I1B!&_O?JZP(>\]P@1M_X9+'^]RCM,4:G
M\40`I_$P"0'PL_BG\44%^T2G\3$&3$85^`$O($9;1@$A`C0`DD_P_S+^]Y;L
MKD+RT0`AS?@(D,WX`(!01@?X"!Q'2DA+2$EZ1'M$`9)Y1$_P_S(#D0$A_O>`
M[!WG!YM<:``L/_32KB!&_O=8[`,H?_;,KCY)!#@@1'E$_O>0ZP`H"+^C1L'F
M(&!_YQ?X`CQ!*YC1%_@!/$,KE-$[>$@KD=%[>$4KCM%/\/\S;_`Y`B!&`);^
M]_CK*48I(B!&_O>`ZRM++$E/\/\R>T0#DRI+>4101@&1>T0!(0*5S?@`@/[W
M/.S9YO[WK.NR9P$`ZF@!``P!``!X9P$`SA<``)`8``#<%@``^!<``'P6``#6
M%P``'`$``.@7``#Z90$`PA<``)07``"(9@$`E!8``!(6``!N%P``#!@``"(5
M```Z%0``'!@``%H7```J%0``+!8``'AD`0!Z%0``U!0``,(4```N$P``3!4`
M`!`6```4%0``E!4``*82``#`%```\+5/](!<K>L,#,SXX`]@2(.P8$EX1&!+
M8$IN1D%8>T0):`&13_```9Q8(&C^]V+L!48@:/[W7NR5^&@@,48#1E=(@_AI
M('A$_O?,_1"Q`W@Q*WK0__<*^B!H_O=,[%%)`R,!(GE$_O>$ZP5&:+$@:/[W
M0.PK:4Q*&6AZ1/[W0NLK:1MHFVA;`F[4(&C^]S+L1DD#(P$B>43^]VKK!49X
ML4-(,49X1/[WG?T'1B!H`"]/T/[W(.PK:3I&&6C^]R+K(&C^]QCL!48@:/[W
M%.PY20$B>43^]W;K-TIZ1`%&*$;^]Q#K(&C^]P;L`"(Q1C--?40#1C)(@_AI
M('A$_O=R_01&J&"PL4_TX'$@1O[W>NM"'`-&$2@8OP$J+]@I2AU+>D336!IH
M`9M:0$_P``,CT0.P\+UH:/_W6_P$1JA@`"CAT2%(>$3^]U#K0W@`*X/0@.?^
M]]#K'4LJ:7M$6V@0:!EH_O>?_JOG(&C^]\3K*VD9:/[W6NN(Y_[WI.H422)&
M%$AY1'A$26@):/[W+NL`O\1A`0`,`0``NF$!`!0!``!:$@``Z!,``-83``#"
M$P``N!$``(H3``":$P``9&(!`%81``"X8`$`.!,``/IA`0#280$`'!,``/"U
M3_2`7*WK#`S,^.`/-TJ#L#=+!T9Z1--8&V@!DT_P``,`*$30`W@`*T'0_O?Z
M_01&(W@[L6(<+RL(OQ1&$O@!.P`K^-$K3CT>?D08OP$E,VA:'#+0`"L,OP`E
M!?`!!5VY)4HB2WI$TU@::`&;6D!/\``#.-$#L/"].W@`*_#0'DD$(B!&>43^
M]RKK`"CHT1M*%TMZ1--8&F@!FUI`3_```R'1.$8#L+WH\$#^]_J\%$AX1/[W
M%.H$1KKG$DAI1GA$_O>C_&BQ`W@`*QB_,"L*OP`C`2,S8,/0`2,S8``MO]#*
MYS!@O.?^]P#JZE\!``P!``#V8`$`FE\!``H1``!L7P$`-@\``"00````````
M+>GP3T_T@%RMZPP,S/A0#=_XB$NM]2-]W_B$.P#Q0`%\1.Y&`/&`#')&XU@`
M)QMHH9-/\``#4>D"9`@Q5V!A1==@-KI/ZA0C%F`#]']#3^H$)4/J%&,"\1`"
M!?1_!4/J!&-#Z@4#0O@(/.31K?$(!@[U_'<`(X1&-$96^`@/(F_4^$B@U.D&
MA6%O@NH*`M3X3)""Z@@"=&A"0('J"0'&^(0P:4!A0)08T@^^0D+J00)"Z@0"
MQOB`(-[1W.D"8F!&W.D`>=[X`$!/ZI8.`6I.ZH)^1_:9$L7V@B+<^!!0I!A/
MZM=L9!A,ZDD<@6E,ZD<<W?@(@!SK!`R%Z@$$-$!.ZH9^3$!/ZI<*'.L$#!CK
M`@2%Z@X(2NJ)>@CJ!PA*ZH=ZB.H%"&08!)D4ZP@$CNH*"`3K_&3=^!B0B1@(
MZ@P(3^J\#$D9BNH,"XCJ#@@+Z@0+$>L("!GK`@D(Z_1H&>L.#D_JM`0(F8OJ
M"@O=^"B0'NL+"XSJ!`Z)&`[J"`X1ZPH*CNH,#@OK^&$:ZPX.3^JX"!GK`@D9
MZPP,A.H("=WX,*`)Z@$)#NOQ;HGJ!`E/ZK$!'.L)#!KK`@F(Z@$*"NH."@SK
M_FP9ZP0)3^J^#@Z<BNH("AGK"@J!Z@X)I!@)Z@P)B>H!"13K"`@8ZPD(W?A`
MD`KK_&1/ZKP,&>L""=WX2*`9ZP$!CNH,"0GJ!`D(Z_1HB>H."4_JM`01ZPD)
M&NL""AKK#@Z,Z@0*%)D*Z@@*">OX:8KJ#`I/ZK@('NL*#HD8A.H("@[K^6X1
MZPP,"NH)"D_JN0'=^%B0BNH$"ASK"@S=^&"@&>L""0SK_FP9ZP0$B.H!"0GJ
M#@E/ZKX.B>H("13K"0D:ZP(*&NL("('J#@H:G`KJ#`H)Z_QIBNH!"D_JO`P8
MZPH(I!B.Z@P*".OY:&$8"NH)"D_JN03=^'"0BNH."A'K"@'=^'B@&>L""0'K
M^&$9ZPX.C.H$"0GJ"`E/ZK@(B>H,"83J"`L>ZPD."^H!"QKK`@K=^("0B^H$
M"QKK#`P.Z_%N'.L+#$_JL0$9ZP()&>L$!(CJ`0D)Z@X)#.O^;(GJ"`E/ZKX.
M%.L)!-WXB)#=^)"@!.O\9!GK`@D9ZP@(@>H."0GJ#`E/ZKP,B>H!"1CK"0F.
MZ@P(&NL""@CJ!`@:ZP$*)IF(Z@X(">OT:1KK"`A/ZK0$BA@(Z_EJ$NL.#HSJ
M!`("Z@D"W?B@@(+J#`)/ZKD)'NL"#D[VH3+&]MEB*ID8ZP((#NOZ;ACK#`B$
MZ@D,C.H*#$_JN@H8ZPP(B1B)Z@H,"1DLG(SJ#@P1ZPP!3^J^#*08".O^:!3K
M"03=^+C@BNH,"0'K^&&)Z@@)3^JX"!3K"00>ZP(.W?C`D![K"@Z,Z@@*!.OQ
M9(KJ`0I/ZK$!'NL*#AGK`@F(Z@$*&>L,#-WXR)"*Z@0*#NOT;ASK"@Q/ZK0$
M&>L""8'J!`H9ZP@)W?C0@`SK_FR*Z@X*3^J^#AGK"@D8ZP((A.H."ACK`0@)
MZ_QAW?C8D(KJ#`I/ZKP,&.L*"!GK`@F.Z@P*&>L$"0CK\63=^."`BNH!"D_J
ML0$9ZPH)&.L""(SJ`0H8ZPX(">OT;MWXZ)"*Z@0*3^JT!!CK"@@9ZP()@>H$
M"AGK#`D(Z_YLW?CP@(KJ#@I/ZKX.&>L*"1CK`@B$Z@X*&.L!"`GK_&'=^/B0
MBNH,"D_JO`P8ZPH(&>L""8[J#`H9ZP0)".OQ9-WX`(&*Z@$*3^JQ`1GK"@D8
MZP((C.H!"ACK#@@)Z_1NW?@(D8KJ!`I/ZK0$&.L*"!GK`@F!Z@0*&>L,#-WX
M$)&*Z@X*".O^:!SK"@Q/ZKX.&>L""83J#@H9ZP$!W?@8D8KJ"`H,Z_AL$>L*
M`4_JN`@9ZP()CNH("AGK!`3=^""1BNH,"@'K_&$4ZPH$3^J\#!GK`@F(Z@P*
M&>L.#MWX*)&*Z@$*!.OQ9![K"@Y/ZK$!&>L""8SJ`0H9ZP@(W?@PD8KJ!`H.
MZ_1N&.L*"$_JM`09ZP()@>H$"AGK#`S=^#B1BNH."@CK_F@<ZPH,3^J^#AGK
M`@)1&(3J#@*"Z@@"W?A`L4_JN`J)&$OVW$+(]AMR#.OX;!OK`@M.Z@H(&^L$
M!-WX2)$.Z@H+".H,"`'K_&%(Z@L(3^J\#!3K"`@9ZP()2NH,!`KJ#`L9ZPX.
M#$#=^%"11.H+!`CK\6@4ZPX.3^JQ`1GK`@D9ZPH*3.H!"0SJ`0M6G`GJ"`D.
MZ_AN2>H+"4_JN`@9ZPH*I!@4ZPP)"NO^9$'J"`I/ZKX,W?A@L0KJ#@H!Z@@.
M2NH.#DCJ#`H>ZPD.&^L""1GK`0D(Z@P+6ID*Z@0*#NOT;DKJ"PI/ZK0$&NL)
M"HD83.H$"0SJ!`L1ZP@(">H."0KK_F'=^'"A3^J^#DGJ"PD$Z@X+&>L("!KK
M`@E$Z@X*&>L,"0KJ`0H(Z_%LW?AX@4KJ"PI/ZK$!&NL)"ACK`@@.Z@$+&.L$
M"0KK_&1.Z@$*W?B`@0KJ#`I/ZKP,2NH+"MWXB+$:ZPD*&.L""!CK#@Y!Z@P(
M`>H,"0CJ!`@*Z_1J2.H)"$_JM`08ZPX.&^L""$SJ!`L.Z_II"^H*"T_JN@X8
MZP$(#.H$"F292^H*"AKK"`A$Z@X*B1@(Z_EH$>L,`0KJ"0I/ZKD,!.H."4KJ
M"0E.Z@P+&>L!"6:9">OX:0OJ"`N)&!'K!`I/ZK@$:)D.Z@P(2^H("$SJ!`L8
MZPH(B1@(Z_EH$>L."@OJ"0M/ZKD.:ID,Z@0)2^H)"1GK"@E$Z@X*B1@)Z_AI
M$>L,`0KJ"`I/ZK@,!.H."$KJ"`A.Z@P+&.L!"&R9".OY:`OJ"0N)&!'K!`I/
MZKD$;ID.Z@P)2^H)"4SJ!`L9ZPH)B1@)Z_AI$>L."@OJ"`M/ZK@.<)D,Z@0(
M2^H("!CK"@A$Z@X*B1@(Z_EH$>L,`0KJ"0I/ZKD,!.H."4KJ"0E.Z@P+&>L!
M"7*9">OX:0OJ"`N)&$-@$>L$"D_JN`0.Z@P(=)E+Z@@(PV`8ZPH(B1@(Z_EJ
M3.H$"!'K#@L(Z@D(3^JY#G:9#.H$"4-A2.H)"`3J#@D8ZPL(BA@2ZPP,1.H.
M`@+J"@)XF4+J"0((Z_IH$NL,#$SRUA+,]F(B3^JZ"A'K`@EZF1GK!`F.Z@H$
MA.H(!`SK^&P9ZP0)3^JX"(D8BNH(!!'K#@Y\F83J#`0)Z_QI'NL$#D_JO`R)
M&(CJ#`01ZPH*?ID.Z_ENA.H)!!KK!`I/ZKD)C!B`F13K"`0*Z_YHC.H)"L-A
MBNH."D_JO@X4ZPH$B1@1ZPP,B>H."H*9!.OX9(KJ"`I/ZK@('.L*"A'K`@P<
MZPD,A)D*Z_1ICNH("HKJ!`I/ZK0$'.L*#(D8$>L.#HCJ!`J&F0SK^6R*Z@D*
M'NL*"D_JN0X1ZP()B)D9ZP@)"NO\:(3J#@J*Z@P*3^J\#!GK"@D1ZP(*&NL$
M"HJ9">OX9([J#`F)Z@@)3^JX"!KK"0H1ZP()&>L."8R9"NOT;HSJ"`J*Z@0*
M3^JT!!GK"@D1ZP(*&NL,"HZ9">O^;(CJ!`F)Z@X)3^J^#AKK"0H1ZP()&>L(
M"9"9"NO\:(3J#@J*Z@P*3^J\#!GK"@D1ZP(*&NL$"I*9">OX9([J#`F)Z@@)
M3^JX"!KK"0H1ZP()&>L."929"NOT;HSJ"`J*Z@0*3^JT!!GK"@D1ZP(*&NL,
M"I:9">O^;(CJ!`F)Z@X)3^J^#AKK"0H1ZP()&>L("9B9"NO\:(3J#@J*Z@P*
M3^J\#!GK"@F)&!'K!`H)Z_ADFIF.Z@P)B>H("4_JN`@:ZPD*B1@1ZPX)"NOT
M;HSJ"`J<F8KJ!`I/ZK0$&>L*"8D8">O^:1'K#`R>F07KN04%88CJ!`6%Z@X%
M3^J^#ASK!0R*&-<9A.H.`@SK^6P7ZP@(@NH)"8%I&.L)"!SK!@8(Z_QB`F`"
M:A[K`0&&8*08"TJ!8<#I"$-Z1`=+TU@::*&;6D!/\``#`]$-]2-]O>CPC_WW
M(.S07@$`#`$``')3`0`(M4_T@%RMZPP,S/CX#X`@_?=:[)_M#GL`(H#M`'N"
M9Y_M#7N`[0)[G^T->X#M!'N?[0U[@.T&>Y_M#7N`[0A[G^T->X#M"GN`[0Q[
M"+T`OP$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M`````````"WI^$-/](!<K>L,#,SXX`^#:@5&`"<61@/KP@P,1IQ%ZVK0Z0PA
M3^KF<'?K`P,#TE,<0?$``1I&<P\%\3@(0^K``\7I"L>;&"MC0>M0<:AO:6.`
MNS\N0]VF\4`)3^J9%G<<!.N'%P3Q0`XA1D-&T?@`P!`Q4?@,3!`S4?@(#%'X
M!"QQ14/X$,Q#^`Q,0_@(#$/X!"SKT2A&#$;_]YWYO$+AT:GKAA8R1CE&0$;]
M]USKKF>]Z/B#P/%`!R%&MT)`1*B_-T8Z1OWW4.NK;SM$JV=`*^[1*$;V&SQ$
M__=]^;GG)T;@YRWI\$%/](!<K>L,#,SXZ`^*:@Q&"VL$\3@'PO/%`9+Z@OA*
M'!ZZ."H%1D_P@`,'ZP(`>U1$W<+Q0`(`(?WW[NL@1O_W5_DX1C@B`"']]^;K
M($;$Z1QH__=-^>-X($8K<&.(:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*JW&C
M:.MQXWPK<F.*:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C,"MT
M8XQK="-J&PJK="-JZW2]Z/!!_??:NL+Q.`(`(?WWJNO!YRWI^$-/](!<K>L,
M#,SXX`\,3@=&#$V(1GY$D49]1/WWBNIV&[80"M`$/0`D5?@$/P$T2D9!1CA&
MF$>F0O;1O>CX@P"_Z$\!`.!/`0!P1P"_`DM[1!MH_??;N@"_LD\!``A`+>D(
M@+WH`0`"`#H````]````"@```#T````/````/0```"0````]````,@```#T`
M```"````/0````4````]````$P```#T````-````/0````P````]````(P``
M`#T````1````/0```"8````]`````0```#T````7````/0````@````]````
M"0```#T``````````````"]T;7``````+@```%!!4E]435!$25(``%1%35!$
M25(`5$U0`%5315(`````55-%4DY!344`````)7,O)7,````O````+W!R;V,O
M<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`4$%27U1%35``````
M4$%27U!23T=.04U%`````#H````E<R5S)7,``%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A
M<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M`!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U
M,@```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#
M86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M
M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L
M;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D
M9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U
M=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@
M,3`R-#L*;7D@)&UA9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE
M*2!["B1M86=I8U]P;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E
M("1C:'5N:U]S:7IE*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T[
M"GT@96QS92!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]
M"G=H:6QE("@D;6%G:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P
M;W,L(#`["G)E860@7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!
M1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I
M8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@
M,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U
M9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@
M)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L
M:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ
M<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO
M*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@
M)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N
M9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA
M;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*
M96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D
M("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L
M("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M
M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L
M93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D
M=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I
M;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R
M(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO
M9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@
M,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D
M("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R
M87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P
M96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@
M)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z
M.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<&%R(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A
M<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N
M)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D
M<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P
M;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.
M5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI
M+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I
M.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!
M3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@
M9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@
M(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M
M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*
M96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M
M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N
M*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F
M:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I
M9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@
M)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;
M4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2![
M"B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC
M;&]S92`D9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT
M96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)
M37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI:
M:7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE
M+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)&]U="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D
M9F@I.PIC;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE
M"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P
M96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.
M5GM005)?5$5-4'TB72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI
M;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D
M:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E
M('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM
M>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\
M.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N
M86UE(CH@)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C
M='@M/FAE>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L
M<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@
M)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@
M)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B
M.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U
M;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O
M<B!D:64@<7%;0V%N)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@
M)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N
M86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL
M;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M
M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%2
M7U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@
M>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.
M5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-
M4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN
M9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A
M)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M
M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S
M("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N
M9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B![
M"FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N
M.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H
M<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@``<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("``````.@```#T````*````/0````\````]````)````#T````R````/0``
M``(````]````!0```#T````3````/0````T````]````#````#T````C````
M/0```!$````]````)@```#T````!````/0```!<````]````"````#T````)
M````/0``````````````F)G_?P$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````R1@``'T8
M``"PC0$``0```"@#```!````.`,```$```!(`P```0```%(#```,````W!(`
M``T````(/@``&0```*B-`0`;````!````!H```"LC0$`'`````0```#U_O]O
MM`$```4````$"@``!@```%0#```*````V@0```L````0````%0`````````#
M````Q(X!``(```#H`0``%````!$````7````]!```!$````4$```$@```.``
M```3````"````!@`````````^___;P$```C^__]OM`\``/___V\#````\/__
M;]X.``#Z__]O$```````````````````````````````````````````````
M``````````"TC0$```````````#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H
M$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2
M``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(`
M`.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``
MZ!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H
M$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``Z!(``.@2``#H$@``]3T`````
M````````````````````````````````````````J3T```````#I%0``````
M`````````````````/____^D/@``K#X```````"P/@``M#X``+P^``!`/P``
MQ#X```````#(/@``T#X```````#800``1T-#.B`H1TY5*2`Q,"XR+C$@,C`R
M,#$Q,C4@*$%,5"!3:7-Y<&AU<R`Q,"XR+C$M86QT,BD`1T-#.B`H1TY5*2`Q
M,"XR+C$@,C`R,3`S,3,@*$%,5"!3:7-Y<&AU<R`Q,"XR+C$M86QT,RD`03(`
M``!A96%B:0`!*`````4W+4$`!@H'00@!"0(*!!($$P$4`14!%P,8`1D!&@(<
M`2(!+4D@+BXO:6YC;'5D90`M22`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M
M,BXS,BUA;'0R+V)U:6QD+6%R;6@M;&EN=7@O8W-U`"U)("]U<W(O<W)C+U)0
M32]"54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>``M22`N
M+B]S>7-D97!S+W5N:7@O<WES=B]L:6YU>"]A<FTO;&4`+4D@+BXO<WES9&5P
M<R]U;FEX+W-Y<W8O;&EN=7@O87)M`"U)("XN+W-Y<V1E<',O87)M+VYP=&P`
M+4D@+BXO<WES9&5P<R]U;FEX+W-Y<W8O;&EN=7@O:6YC;'5D90`M22`N+B]S
M>7-D97!S+W5N:7@O<WES=B]L:6YU>``M22`N+B]S>7-D97!S+VYP=&P`+4D@
M+BXO<WES9&5P<R]P=&AR96%D`"U)("XN+W-Y<V1E<',O9VYU`"U)("XN+W-Y
M<V1E<',O=6YI>"]I;F5T`"U)("XN+W-Y<V1E<',O=6YI>"]S>7-V`"U)("XN
M+W-Y<V1E<',O=6YI>"]A<FT`+4D@+BXO<WES9&5P<R]U;FEX`"U)("XN+W-Y
M<V1E<',O<&]S:7@`+4D@+BXO<WES9&5P<R]A<FTO;&4O87)M=C<O;75L=&EA
M<F-H`"U)("XN+W-Y<V1E<',O87)M+V%R;78W+VUU;'1I87)C:``M22`N+B]S
M>7-D97!S+V%R;2]L92]A<FUV-P`M22`N+B]S>7-D97!S+V%R;2]A<FUV-P`M
M22`N+B]S>7-D97!S+V%R;2]A<FUV-G0R`"U)("XN+W-Y<V1E<',O87)M+V%R
M;78V`"U)("XN+W-Y<V1E<',O87)M+VQE`"U)("XN+W-Y<V1E<',O87)M+VEN
M8VQU9&4`+4D@+BXO<WES9&5P<R]A<FT`+4D@+BXO<WES9&5P<R]W;W)D<VEZ
M92TS,@`M22`N+B]S>7-D97!S+VEE964W-30O9FQT+3,R`"U)("XN+W-Y<V1E
M<',O:65E93<U-"]D8FPM-C0`+4D@+BXO<WES9&5P<R]I965E-S4T`"U)("XN
M+W-Y<V1E<',O9V5N97)I8P`M22`N+@`M22`N+B]L:6)I;P`M22`N`"U-1"`O
M=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%R;6@M
M;&EN=7@O8W-U+V%B:2UN;W1E+F0`+4U&("]U<W(O<W)C+U)032]"54E,1"]G
M;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O86)I+6YO=&4N
M;RYD=``M35``+4U4("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L
M=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O86)I+6YO=&4N;P`M1"!35$%#2U]0
M4D]414-43U)?3$5614P],``M52!?1D]25$E&65]33U520T4`+40@7TQ)0D-?
M4D5%3E1204Y4`"U$($U/1%5,15].04U%/6QI8F,`+40@4$E#`"U$(%1/4%].
M04U%4U!!0T4]9VQI8F,`+6EN8VQU9&4@+W5S<B]S<F,O4E!-+T)524Q$+V=L
M:6)C+3(N,S(M86QT,B]B=6EL9"UA<FUH+6QI;G5X+VQI8F,M;6]D=6QE<RYH
M`"UI;F-L=61E("XN+VEN8VQU9&4O;&EB8RUS>6UB;VQS+F@`86)I+6YO=&4N
M8P`M9G-T86-K+6-L87-H+7!R;W1E8W1I;VX`+6UT:'5M8@`M;71U;F4]8V]R
M=&5X+6$X`"UM9FQO870M86)I/6AA<F0`+6UF<'4]=F9P=C,M9#$V`"UM86)I
M/6%A<&-S+6QI;G5X`"UM=&QS+61I86QE8W0]9VYU`"UM87)C:#UA<FUV-RUA
M*V9P`"UA=7AB87-E+7-T<FEP("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR
M+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O86)I+6YO=&4N;P`M9P`M
M3S(`+5=A;&P`+5=W<FET92US=')I;F=S`"U7=6YD968`+5=E<G)O<@`M5W-T
M<FEC="UP<F]T;W1Y<&5S`"U7;VQD+7-T>6QE+61E9FEN:71I;VX`+7-T9#UG
M;G4Q,0`M9F=N=3@Y+6EN;&EN90`M9G)E8V]R9"UG8V,M<W=I=&-H97,`+69M
M97)G92UA;&PM8V]N<W1A;G1S`"UF<F]U;F1I;F<M;6%T:``M9G-T86-K+7!R
M;W1E8W1O<BUS=')O;F<`+69M871H+65R<FYO`"UF;VUI="UF<F%M92UP;VEN
M=&5R`"UF;F\M<W1A8VLM<')O=&5C=&]R`"UF=&QS+6UO9&5L/6EN:71I86PM
M97AE8P`M340@+W5S<B]S<F,O4E!-+T)524Q$+V=L:6)C+3(N,S(M86QT,B]B
M=6EL9"UA<FUH+6QI;G5X+V-S=2]I;FET+F0`+4U&("]U<W(O<W)C+U)032]"
M54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O:6YI
M="YO+F1T`"U-5"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R
M+V)U:6QD+6%R;6@M;&EN=7@O8W-U+VEN:70N;P`M875X8F%S92US=')I<"`O
M=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD+6%R;6@M
M;&EN=7@O8W-U+VEN:70N;P`M22`O=7-R+VQO8V%L+VEN8VQU9&4`+4D@+W5S
M<B]L:6(O<&5R;#4O0T]210`M1"!?4D5%3E1204Y4`"U$(%]'3E5?4T]54D-%
M`"U$(%],05)'149)3$5?4T]54D-%`"U$(%]&24Q%7T]&1E-%5%]"2513/38T
M`"U$($Q$3$E"4%1(3D%-13TB3$1?3$E"4D%265]0051((@`M1"!005),7T58
M13TB<&%R;"(`+40@4$%27U!!0TM%4E]615)324]./2(Q+C`U,B(`;6%I;BYC
M`"UF=W)A<'8`+69N;RUS=')I8W0M86QI87-I;F<`+40@0EE414]21$52/3!X
M,3(S-#4V-S@`+40@538T5%E013UU;G-I9VYE9"!L;VYG(&QO;F<`<VAA,2YC
M`"U-1"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI8F,M,BXS,BUA;'0R+V)U:6QD
M+6%R;6@M;&EN=7@O8W-U+V5L9BUI;FET+F0`+4U&("]U<W(O<W)C+U)032]"
M54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O96QF
M+6EN:70N;U,N9'0`+4U4("]U<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C,R
M+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]C<W4O96QF+6EN:70N;U,`+40@3$E"
M0U].3TY32$%2140],0!E;&8M:6YI="YC`"UA=7AB87-E+7-T<FEP("]U<W(O
M<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU
M>"]C<W4O96QF+6EN:70N;U,`+69024,`+4D@+W5S<B]S<F,O4E!-+T)524Q$
M+V=L:6)C+3(N,S(M86QT,B]B=6EL9"UA<FUH+6QI;G5X+VYP=&P`+4U$("]U
M<W(O<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL
M:6YU>"]N<'1L+W!T:')E861?871F;W)K+F0`+4U&("]U<W(O<W)C+U)032]"
M54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU>"]N<'1L+W!T
M:')E861?871F;W)K+F]3+F1T`"U-5"`O=7-R+W-R8R]24$TO0E5)3$0O9VQI
M8F,M,BXS,BUA;'0R+V)U:6QD+6%R;6@M;&EN=7@O;G!T;"]P=&AR96%D7V%T
M9F]R:RYO4P!P=&AR96%D7V%T9F]R:RYC`"UA=7AB87-E+7-T<FEP("]U<W(O
M<W)C+U)032]"54E,1"]G;&EB8RTR+C,R+6%L=#(O8G5I;&0M87)M:"UL:6YU
M>"]N<'1L+W!T:')E861?871F;W)K+F]3````"`````@``````0``1T$D`3-A
M,0`<&```S!@```@````(``````$``$=!)`$S83$`"#X```@^````+G-H<W1R
M=&%B`"YI;G1E<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV
M97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P`N1T-#+F-O;6UA;F0N;&EN90`N
M9VYU+F)U:6QD+F%T=')I8G5T97,`````````````````````````````````
M````````````````````````"P````$````"````5`$``%0!```9````````
M```````!`````````!,````'`````@```'`!``!P`0``)```````````````
M!``````````F````!P````(```"4`0``E`$``"````````````````0`````
M````-````/;__V\"````M`$``+0!``"@`0``!0`````````$````!````#X`
M```+`````@```%0#``!4`P``L`8```8````#````!````!````!&`````P``
M``(````$"@``!`H``-H$``````````````$`````````3@```/___V\"````
MW@X``-X.``#6````!0`````````"`````@```%L```#^__]O`@```+0/``"T
M#P``8`````8````#````!`````````!J````"0````(````4$```%!```.``
M```%``````````0````(````<P````D```!"````]!```/00``#H`0``!0``
M`!8````$````"````'P````!````!@```-P2``#<$@``#```````````````
M!`````````!W`````0````8```#H$@``Z!(````#``````````````0````$
M````@@````$````&````Z!4``.@5```@*``````````````(`````````(@`
M```!````!@````@^```(/@``"```````````````!`````````".`````0``
M``(````0/@``$#X```A```````````````0`````````E@````$``'""````
M&'X``!A^```(````#0`````````$`````````*$````!`````P```*2-`0"D
MC0``!```````````````!`````````"K````#@````,```"HC0$`J(T```0`
M``````````````0````$````MP````\````#````K(T!`*R-```$````````
M```````$````!````,,````!`````P```+"-`0"PC0``!```````````````
M!`````````#0````!@````,```"TC0$`M(T``!`!```&``````````0````(
M````V0````$````#````Q(X!`,2.```\`0`````````````$````!````-X`
M```!`````P````"0`0``D```/```````````````!`````````#D````"```
M``,````\D`$`/)```!00``````````````0`````````Z0````$````P````
M`````#R0``!L```````````````!`````0```/(````#``!P``````````"H
MD```,P```````````````0`````````"`0```0```#``````````VY```#<,
M``````````````$````!````%`$```<`````````4*`!`!2=```X````````
M```````$``````````$````#``````````````!,G0``*@$`````````````
(`0``````````
